tlslite

Package tlslite |
[hide private]
[frames] | no frames]

# Source Code for Package tlslite

     1  # Author: Trevor Perrin
     2  # See the LICENSE file for legal information regarding use of this file.
     3
     4  """TLS Lite is a free python library that implements SSL and TLS. TLS Lite
     5  supports RSA and SRP ciphersuites. TLS Lite is pure python, however it can use
     6  other libraries for faster crypto operations. TLS Lite integrates with several
     7  stdlib neworking libraries.
     8
     9  API documentation is available in the 'docs' directory.
    10
    11  If you have questions or feedback, feel free to contact me.
    12
    13  To use, do::
    14
    15      from tlslite import TLSConnection, ...
    16
    17  If you want to import the most useful objects, the cleanest way is:
    18
    19      from tlslite.api import *
    20
    21  Then use the L{tlslite.TLSConnection.TLSConnection} class with a socket.
    22  (Or, use one of the integration classes in L{tlslite.integration}).
    23
    24  @version: 0.4.3
    25  """
    26
    27  from tlslite.api import *
    28  from tlslite.api import __version__ # Unsure why this is needed, but it is
    29